==> kblinsel-0.1.2.tar.gz: kblinsel-0.1.2/kblinsel/kblinsel.moc.cpp <==
/****************************************************************************
** KBlinsel meta object code from reading C++ file 'kblinsel.h'
**
** Created: Wed Mar 24 15:49:08 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "kblinsel.h"
#include <qmetaobject.h>


const char *KBlinsel::className() const
{
    return "KBlinsel";
}

QMetaObject *KBlinsel::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KBlinsel(&KBlinsel::staticMetaObject);

#endif

void KBlinsel::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTMainWindow::className(), "KTMainWindow") != 0 )
	badSuperclassWarning("KBlinsel","KTMainWindow");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KBlinsel::staticMetaObject()
{
    if ( metaObj )
	return;
    KTMainWindow::staticMetaObject();
#else

    KTMainWindow::initMetaObject();
#endif

    typedef void(KBlinsel::*m1_t0)(KDNDDropZone*);
    typedef void(KBlinsel::*m1_t1)(int);
    typedef void(KBlinsel::*m1_t2)(int);
    typedef void(KBlinsel::*m1_t3)(int);
    m1_t0 v1_0 = &KBlinsel::slotDropEvent;
    m1_t1 v1_1 = &KBlinsel::slotToolbarClicked;
    m1_t2 v1_2 = &KBlinsel::slotToolbarToggled;
    m1_t3 v1_3 = &KBlinsel::showProgress;
    QMetaData *slot_tbl = new QMetaData[4];
    slot_tbl[0].name = "slotDropEvent(KDNDDropZone*)";
    slot_tbl[1].name = "slotToolbarClicked(int)";
    slot_tbl[2].name = "slotToolbarToggled(int)";
    slot_tbl[3].name = "showProgress(int)";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    metaObj = new QMetaObject( "KBlinsel", "KTMainWindow",
	slot_tbl, 4,
	0, 0 );
}

==> kblinsel-0.1.3.tar.gz: kblinsel-0.1.3/kblinsel/kblinsel.moc.cpp <==
/****************************************************************************
** KBlinsel meta object code from reading C++ file 'kblinsel.h'
**
** Created: Sat Apr 10 20:00:55 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "kblinsel.h"
#include <qmetaobject.h>


const char *KBlinsel::className() const
{
    return "KBlinsel";
}

QMetaObject *KBlinsel::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_KBlinsel(&KBlinsel::staticMetaObject);

#endif

void KBlinsel::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(KTMainWindow::className(), "KTMainWindow") != 0 )
	badSuperclassWarning("KBlinsel","KTMainWindow");

#if QT_VERSION >= 200
    staticMetaObject();
}

void KBlinsel::staticMetaObject()
{
    if ( metaObj )
	return;
    KTMainWindow::staticMetaObject();
#else

    KTMainWindow::initMetaObject();
#endif

    typedef void(KBlinsel::*m1_t0)(KDNDDropZone*);
    typedef void(KBlinsel::*m1_t1)(int);
    typedef void(KBlinsel::*m1_t2)(int);
    typedef void(KBlinsel::*m1_t3)(int);
    typedef void(KBlinsel::*m1_t4)();
    m1_t0 v1_0 = &KBlinsel::slotDropEvent;
    m1_t1 v1_1 = &KBlinsel::slotToolbarClicked;
    m1_t2 v1_2 = &KBlinsel::slotToolbarToggled;
    m1_t3 v1_3 = &KBlinsel::showProgress;
    m1_t4 v1_4 = &KBlinsel::theend;
    QMetaData *slot_tbl = new QMetaData[5];
    slot_tbl[0].name = "slotDropEvent(KDNDDropZone*)";
    slot_tbl[1].name = "slotToolbarClicked(int)";
    slot_tbl[2].name = "slotToolbarToggled(int)";
    slot_tbl[3].name = "showProgress(int)";
    slot_tbl[4].name = "theend()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    slot_tbl[2].ptr = *((QMember*)&v1_2);
    slot_tbl[3].ptr = *((QMember*)&v1_3);
    slot_tbl[4].ptr = *((QMember*)&v1_4);
    metaObj = new QMetaObject( "KBlinsel", "KTMainWindow",
	slot_tbl, 5,
	0, 0 );
}
